@@ -630,7 +630,7 @@ screenshot_get_pixbuf (GdkRectangle *rectangle)
                                      filename);
     }
 
-  connection = screenshot_application_get_session_bus ();
+  connection = g_application_get_dbus_connection (g_application_get_default ());
   g_dbus_connection_call_sync (connection,
                                "org.gnome.Shell",
                                "/org/gnome/Shell",
@@ -653,8 +653,8 @@ screenshot_get_pixbuf (GdkRectangle *rectangle)
 
   if (error != NULL)
     {
-      g_warning ("Unable to use GNOME Shell's builtin screenshot interface, "
-                 "resorting to fallback X11. Error: %s", error->message);
+      g_message ("Unable to use GNOME Shell's builtin screenshot interface, "
+                 "resorting to fallback X11.");
       g_error_free (error);
 
       screenshot = screenshot_fallback_get_pixbuf (rectangle);
